@@ -28,8 +28,9 @@ class Logger:
     - `logfile` - Optional. Path to the file to also write log messages to.
     - `timestamp_format` - Optional. Format of the timestamp as accepted by `datetime.datetime.strftime` method. Defaults to "%y/%m/%d-%H:%M:%S.%f"."""
     
-    def __init__(self, logfile: Optional[str] = None, timestamp_format: Optional[str] = "%y/%m/%d-%H:%M:%S.%f"):
+    def __init__(self, logfile: Optional[str] = None, *, timestamp_format: Optional[str] = "%y/%m/%d-%H:%M:%S.%f", encoding: str = 'utf8'):
         self.filepath = logfile
+        self.encoding = encoding
         self.timestamp_format = timestamp_format
         if logfile:
             makedirs(path.abspath(path.dirname(logfile)), exist_ok=True)
@@ -44,19 +45,21 @@ class Logger:
         if not file and not self.filepath:
             raise ValueError("Neither log file nor file argument specified")
         
-        sio = StringIO()
-        
-        timestamp = datetime.now().strftime(self.timestamp_format)
-        print(f'[{level.name} - {timestamp}]', *args, file=sio)
-        sio.seek(0)
-        msg = sio.read()
+        msg = self._buildmsg(level, args)
         
         if file:
             file.write(msg)
         
         if self.filepath:
-            with open(self.filepath, 'a') as fd:
-                fd.write(msg)
+            with open(self.filepath, 'ab') as fd:
+                fd.write(msg.encode(self.encoding))
+    
+    def _buildmsg(self, level: LogLevel, args: Sequence):
+        sio = StringIO()
+        timestamp = datetime.now().strftime(self.timestamp_format)
+        print(f'[{level.name} - {timestamp}]', *args, file=sio)
+        sio.seek(0)
+        return sio.read()
     
     def v(self, *args, file: Optional[typing.IO] = stdout):
         """Shortcut for `log(LogLevel.VERBOSE, *args, file=file)`."""
